Cabric
==================
A deploy tool for Centos, base on Fabric.

FAQ
----------------------------
`Chinese Version <https://github.com/nextoa/cabric/blob/master/docs/faq.rst>`_


Release Note
----------------------------


* 0.8.x
    * support deploy php
    * support more config type
    * improve install python lxml
    * support tengine
    * support nginx
    * support python3,pypy
    * support python complex package.e.g:pillow
    * support redis
    * support mongodb
    * support mysql
    * core feature
        * add user
        * git clone/git pull code
        * upload private | public key
        * ...





